@@ -123,6 +123,8 @@ class Camera(BaseCamera):
     hasAudioDetector: bool
     hasMotionDetector: bool
     hasObjectDetector: bool
+    hasPrebuffer: bool
+    hasIntercom: bool
     hasPtz: bool
     sources: List[CameraInput]
 
